@@ -47,14 +47,11 @@
 #include <KUrlCompletion>   //locationbar
 
 #include <QApplication>     //setupActions()
-#include <QByteArray>
 #include <QDir>
 #include <QFileDialog>
-#include <QLineEdit>
-#include <QObject>
 #include <QScrollArea>
 #include <QStatusBar>
-#include <QToolTip>
+#include <QLineEdit>
 
 namespace Filelight {
 
@@ -249,7 +246,7 @@ void MainWindow::slotComboScan()
     QUrl url = QUrl::fromUserInput(path);
 
     if (url.isRelative())
-        path = QStringLiteral("~/") + path; // KUrlCompletion completes relative to ~, not CWD
+        path = QLatin1String("~/") + path; // KUrlCompletion completes relative to ~, not CWD
 
     path = KShell::tildeExpand(path);
 
